@@ -1,4 +1,6 @@
 import logging
+from datetime import datetime
+from typing import List, Dict, Union
 
 from labelbox.orm import query
 from labelbox.orm.db_object import DbObject, Updateable, BulkDeletable
@@ -18,13 +20,14 @@ class DataRow(DbObject, Updateable, BulkDeletable):
         updated_at (datetime)
         created_at (datetime)
         media_attributes (dict): generated media attributes for the datarow
+        metadata (dict): uploaded metadata
 
         dataset (Relationship): `ToOne` relationship to Dataset
         created_by (Relationship): `ToOne` relationship to User
         organization (Relationship): `ToOne` relationship to Organization
         labels (Relationship): `ToMany` relationship to Label
-        metadata (Relationship): `ToMany` relationship to AssetMetadata
-        predictions (Relationship): `ToMany` relationship to Prediction
+        attachments (Relationship) `ToMany` relationship with AssetAttachment
+        metadata (Relationship): This Relationship is Deprecated. Please use `DataRow.attachments()` instead
     """
     external_id = Field.String("external_id")
     row_data = Field.String("row_data")
@@ -37,21 +40,42 @@ class DataRow(DbObject, Updateable, BulkDeletable):
     created_by = Relationship.ToOne("User", False, "created_by")
     organization = Relationship.ToOne("Organization", False)
     labels = Relationship.ToMany("Label", True)
-
-    metadata = Relationship.ToMany(
-        "AssetMetadata",
-        False,
-        "metadata",
-        deprecation_warning=
-        "`DataRow.metadata()` is deprecated. Use `DataRow.attachments()` instead."
-    )
     attachments = Relationship.ToMany("AssetAttachment", False, "attachments")
-    predictions = Relationship.ToMany("Prediction", False)
 
-    supported_meta_types = supported_attachment_types = {
-        attachment_type.value
-        for attachment_type in AssetAttachment.AttachmentType
-    }
+    supported_meta_types = supported_attachment_types = set(
+        AssetAttachment.AttachmentType.__members__)
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.attachments.supports_filtering = False
+        self.attachments.supports_sorting = False
+
+    @property
+    def metadata(self) -> Dict[str, Union[str, List[Dict]]]:
+        """Get metadata for datarow
+        """
+
+        query = """query GetDataRowMetadataBetaPyApi($dataRowID: ID!) {
+              dataRow(where: {id: $dataRowID}) {
+                customMetadata {
+                    value
+                    schemaId
+                }
+              }
+            }
+        """
+
+        metadata = self.client.execute(
+            query, {"dataRowID": self.uid})["dataRow"]["customMetadata"]
+
+        return {
+            "data_row_id":
+                self.uid,
+            "fields": [{
+                "schema_id": m["schemaId"],
+                "value": m["value"]
+            } for m in metadata]
+        }
 
     @staticmethod
     def bulk_delete(data_rows):
@@ -62,32 +86,22 @@ class DataRow(DbObject, Updateable, BulkDeletable):
         """
         BulkDeletable._bulk_delete(data_rows, True)
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.metadata.supports_filtering = False
-        self.metadata.supports_sorting = False
-        self.attachments.supports_filtering = False
-        self.attachments.supports_sorting = False
-
     def create_attachment(self, attachment_type, attachment_value):
-        """ Attaches asset metadata to a DataRow.
+        """ Adds an AssetAttachment to a DataRow.
+            Labelers can view these attachments while labeling.
 
             >>> datarow.create_attachment("TEXT", "This is a text message")
 
         Args:
-            meta_type (str): Asset attachment type, must be one of:
+            attachment_type (str): Asset attachment type, must be one of:
                 VIDEO, IMAGE, TEXT, IMAGE_OVERLAY (AssetAttachment.AttachmentType)
-            meta_value (str): Asset attachment value.
+            attachment_value (str): Asset attachment value.
         Returns:
             `AssetAttachment` DB object.
         Raises:
             ValueError: asset_type must be one of the supported types.
         """
-
-        if attachment_type not in self.supported_attachment_types:
-            raise ValueError(
-                f"meta_type must be one of {self.supported_attachment_types}. Found {attachment_type}"
-            )
+        AssetAttachment.validate_attachment_type(attachment_type)
 
         attachment_type_param = "type"
         attachment_value_param = "value"
@@ -108,21 +122,3 @@ class DataRow(DbObject, Updateable, BulkDeletable):
             })
         return Entity.AssetAttachment(self.client,
                                       res["createDataRowAttachment"])
-
-    def create_metadata(self, meta_type, meta_value):
-        """
-
-        This function is deprecated. Use create_attachment instead
-
-        Returns:
-            AssetMetadata
-        """
-        logger.warning(
-            "`create_metadata` is deprecated. Use `create_attachment` instead.")
-        attachment = self.create_attachment(meta_type, meta_value)
-        return Entity.AssetMetadata(
-            self.client, {
-                'id': attachment.uid,
-                'metaType': attachment.attachment_type,
-                'metaValue': attachment.attachment_value
-            })
